import time

__version__ = "0.11.1"
__author__ = "Lightning AI et al."
__author_email__ = "pytorch@lightning.ai"
__license__ = "Apache-2.0"
__copyright__ = f"Copyright (c) 2022-{time.strftime('%Y')}, {__author__}."
__homepage__ = "https://github.com/Lightning-AI/utilities"
__docs__ = "Lightning toolbox for across the our ecosystem."
__long_doc__ = """
This package allows for sharing GitHub workflows, CI/CD assistance actions, and Python utilities across the Lightning
ecosystem - projects.
"""

__all__ = [
    "__author__",
    "__author_email__",
    "__copyright__",
    "__docs__",
    "__homepage__",
    "__license__",
    "__version__",
]
